#!/bin/ksh
#> This script will install NortelGGU - NorGPRS_Radio module
#> patch: 4.0.14.0.20
#

# variables used after <productVersion> and <wsVersion> drop.
export NEPATCH_START_DIR=`pwd`
export ARCHIVE_DIR=$NEPATCH_START_DIR/Archive
export BACKUP_DIR=$NEPATCH_START_DIR/Backup

########################################################
# Check system values required for this module but not checked by the
# main installer.
if [[ -z $FLEXPM_HOME ]]; then
  echo "+> FLEXPM_HOME environment is not defined"
  echo "+> Please ensure that this is defined and then reinstall upgrade"
  echo ""
  exit 2
fi

if [[ ! -d $FLEXPM_HOME ]]; then
  echo "+> FLEXPM_HOME environment value '$FLEXPM_HOME'"
  echo "+> is not a valid directory. Please check this value"
  echo ""
  exit 2
fi

########################################################
# Check system values required for this module but not checked by the
# main installer.
if [[ -z $NorGPRS_Radio_HOME ]]; then
  echo "+> NorGPRS_Radio_HOME environment is not defined"
  echo "+> Please ensure that this is defined and then reinstall upgrade"
  echo ""
  exit 2
fi

if [[ ! -d $NorGPRS_Radio_HOME ]]; then
  echo "+> NorGPRS_Radio_HOME environment value '$NorGPRS_Radio_HOME'"
  echo "+> is not a valid directory. Please check this value"
  echo ""
  exit 2
fi

# Begin the upgrade
echo "+ Installing NorGPRS_Radio component upgrades ... "
date +"+ Component upgrade is started at %T, %D ... "

cd ${NEPATCH_START_DIR}
if [ ! -d $BACKUP_DIR ]
then
  mkdir $BACKUP_DIR
fi

echo ""
echo "+ Backing up original NorGPRS_Radio module files ..."
cd $NorGPRS_Radio_HOME
for file in `gtar -tzf ${NEPATCH_START_DIR}/NorGPRS_Radio_1.0.tgz`
do
  if [ -f $file ]
  then
    if [ ! -d ${ARCHIVE_DIR}/`dirname $file` ]
    then
      mkdir -p ${ARCHIVE_DIR}/`dirname $file`
    fi
    cp $file ${ARCHIVE_DIR}/`dirname $file`
    chmod +w $file
  fi
done

cd $NEPATCH_START_DIR/Archive
gtar -czf ../Module_Archive_`date '+%y%m%d_%H%M%S'`.tar.gz *
cd $NEPATCH_START_DIR
rm -rf ${ARCHIVE_DIR}
mv -f Module_Archive*.tar.gz $BACKUP_DIR/
cd $NorGPRS_Radio_HOME

echo "+ Installing new/updated files for NorGPRS_Radio module ..."
gtar -xvzf ${NEPATCH_START_DIR}/NorGPRS_Radio_1.0.tgz

cd $NorGPRS_Radio_HOME/peik
make dict_update

cd $NorGPRS_Radio_HOME/vendor/Nortel/GPRS_Radio/1.3/scripts
make clean
make all

cd $NorGPRS_Radio_HOME/vendor/Nortel/GPRS_Radio/1.3/NorGPRS_Radio_data
make clean
make all

cd $NorGPRS_Radio_HOME/vendor/Nortel/GPRS_Radio/1.3/NorGPRS_Radio_loader/PCUSN   
make clean
make all

date +"+ NorGPRS_Radio component upgrade is completed at %T, %D ....."
echo ""
exit 0
$
